#!/bin/bash
 
CURRENT_DIR=`pwd`


echo "installing RunMC:"  

#
# define here path to CERNLIB
# CERN_DIR="/home/sergei/cern/pro/lib"
CERN_DIR="/cern/pro/lib"
#
# Change to address of your CLHEP headers
# CLHEPINC="/home/sergei/cern/clhep/include"
CLHEPINC="/opt/products/CLHEP/1.8.2.0/include"
#
#
# include path to CLHEP library here  
# CLHEP_DIR="/home/sergei/cern/clhep/lib"
CLHEP_DIR="/opt/products/CLHEP/1.8.2.0/lib"
#
# specify name of CLHEP libarry 
# do this without "lib" in front and the extention ".a"
# NAME_CLHEP="CLHEP-g++.1.8.1.0"
NAME_CLHEP="CLHEP-g++.1.8.2.0"
#
# define here name of the PDF librarry (without lib in front) from CERNLIB
NAME_PDFLIB="pdflib804"

# define here some additional library (if you need it for some reasons)
MYLIB=
#
# define additional include files
MYINCLUDE=

# specify compilers here (do not change this part!) 
CXX="g++"
CC="gcc"
F77="g77"
AR="ar"



######################################################################
# do not modify this part !!!
# only for experts
############################### do checks #############################
# is this linux
OSYSTEM=`uname`
if [ "$OSYSTEM" != "Linux" ]
then
echo "operating system=$OSYSTEM, this is not Linux! Stop";
exit 1;
fi


fcheck=`type -p $CC`
if test -x "$fcheck"; 
then
    echo " $fcheck -> OK $CC exists" 
else
    echo "Error: $CC does not exists"
    exit 0;
fi


fcheck=`type -p $CXX`
if test -x "$fcheck";
then
    echo " $fcheck -> OK $CXX exists"
else
    echo "Error: $CXX does not exists"
    exit 0;
fi

fcheck=`type -p $F77`
if test -x "$fcheck";
then
    echo " $fcheck -> OK $F77 exists"
else
    echo "Error: $F77 does not exists"
    exit 0;
fi


fcheck=`type -p $AR`
if test -x "$fcheck";
then
    echo " $fcheck -> OK $AR  exists"
else
    echo "Error: $AR does not exists"
    exit 0;
fi


fcheck=`type -p ranlib`
if test -x "$fcheck";
then
    echo " $fcheck -> OK ranlib exists"
else
    echo "Error: ranlib does not exists"
    exit 0;
fi


fcheck=`type -p zip`
if test -x "$fcheck";
then
    echo " $fcheck -> OK zip exists"
else
    echo "Error: zip/unzip does not exists"
    exit 0;
fi

fcheck=`type -p sed`
if test -x "$fcheck";
then
    echo " $fcheck -> OK sed exists"
else
    echo "Error: sed does not exists"
    exit 0;
fi

fcheck=`type -p h2root`
if test -x "$fcheck";
then
    echo " $fcheck -> OK h2root exists"
else
    echo "Error: h2root does not exists. Is ROOT installed?"
    exit 0;
fi



fcheck="/usr/lib/termcap/libtermcap.a"
if test -e "$fcheck";
then
    echo " $fcheck -> OK libtermcap.a exists"
else
    echo "Error: Check your linux or cygwin distro!" 
    echo "Error: To compile CASCADE, you need to install \"libtermcap.a\""
    echo "Error: RunMC expects this library in the standard place: "
    echo "$fcheck" 
    exit 0;
fi

mathlib=$CERN_DIR"/libmathlib.a"
pdflib=$CERN_DIR"/lib"$NAME_PDFLIB".a"
packlib=$CERN_DIR"/libpacklib.a"
kernlib=$CERN_DIR"/libkernlib.a"
incTROOT=$ROOTSYS"/include/TROOT.h"  
libCLHEPLIB=$CLHEP_DIR/"lib"$NAME_CLHEP".a"
incCLHEPLIB=$CLHEPINC/"CLHEP/config/CLHEP.h" 
incCLHEPvector=$CLHEPINC"/CLHEP/Vector/LorentzVector.h"
makeCLHEPLIB="-l"$NAME_CLHEP


## test invaromental variable 
if [ ! -f $RUNMC"/build/install.sh" ]
then
echo "You did not set \$RUNMC to correctly !  Stop installation"; 
echo "Example: \$RUNMC/build/install.sh should point to this script"  exit 1; 
else
echo " \$RUNMC set to $RUNMC  -> OK";
fi




## check cernlib libraries
if [ ! -e $mathlib ]
then
echo "cannot find $mathlib !  Stop installation"; exit 1; 
else
echo " $mathlib  -> OK"; 
fi

## check cernlib libraries
if [ ! -e $packlib ]
then
echo "cannot find $packlib !  Stop installation"; exit 1;
else
echo " $packlib   -> OK";
fi

## check cernlib libraries
if [ ! -e $kernlib ]
then
echo "cannot find $kernlib !  Stop installation"; exit 1;
else
echo " $kernlib  -> OK";
fi


## check cernlib libraries
if [ ! -e $pdflib ]
then
echo "cannot find $pdflib !  Stop installation"; exit 1;
else
echo " $pdflib  -> OK";
fi

## fast check for root existence 
if [ ! -e $incTROOT ]
then
echo "cannot find ROOT include files !  Is ROOT installed? Stop installation"; exit 1;
else
echo " $ROOTSYS/include/    \"include\" files -> OK";
fi

## fast check for root existence
if [ ! -f $libCLHEPLIB ]
then
echo "cannot find $libCLHEPLIB ! Is CLHEPLIB installed? Stop installation"; exit 1;
else
echo " $libCLHEPLIB found -> OK"
fi



## fast check for CLHEP include existence
if [ ! -f $incCLHEPLIB ]
then
echo "cannot find $incCLHEPLIB ! -> Are CLHEPLIB include files installed? Stop installation"; exit 1;
else
echo " $incCLHEPLIB   -> OK"
fi

## fast check for CLHEP include existence
if [ ! -f $incCLHEPvector ]
then
echo "cannot find $incCLHEPvector -> Are CLHEPLIB include files installed? Stop installation"; exit 1;
else
echo " $incCLHEPvector  -> OK"
fi



installog=$CURRENT_DIR"/install.log" 
if [ -f $installog ]
then
rm -f $installog
fi

if [ -f "Makefile.in" ]
then
rm -f "Makefile.in"
fi


echo " "


### for checking status
cp -f  $RUNMC"/build/auxil/Makefile" "$RUNMC/build/auxil/check.pipe" 

############################################################
############## making include Makefile ######################
cat > $CURRENT_DIR/Makefile.in <<!
#file generated by install.sh script (S.Chekanov) 

# CERNLIB location 
CERN_DIR = $CERN_DIR

# Change to address of your CLHEP headers
CLHEPINC     =  $CLHEPINC
#
#
# Change to address of your CLHEP library
CLHEP_DIR     = $CLHEP_DIR
#
#
# define here some additional library (if you need it for some reasons)
MYLIB         =
#
# define additional include files
MYINCLUDE     =
#
#
SRC_HOME = \$(shell pwd)

# Compilers
CXX          = $CXX 
FORTCOM      = $F77
OBJDIR       = ./
CC           = $CC
F77          = $F77
DEBUGCXX     = -Wall -Wno-format -fPIC -O2
DEBUGF77     = -O
 
# Root variables
# Root variables
ROOTCFLAGS    = \$(shell root-config --cflags)
ROOTLIBS      = \$(shell root-config --libs)
ROOTGTTLIBS   = \$(shell root-config --glibs)
ROOTLIBS     += -lMinuit
# Assign or add variables
CERN          = -L\$(CERN_DIR)  -l$NAME_PDFLIB -lmathlib  -lpacklib -lkernlib -lm -lg2c
CLHEP         = -L\$(CLHEP_DIR) $makeCLHEPLIB
CXXFLAGS     += \$(ROOTCFLAGS)
LIBS         += \$(ROOTLIBS) \$(CERN) \$(CLHEP) \$(MYLIB)
MYINC         =../inc
ALL_INCLUDES =  \$(ROOTCFLAGS) -Iinc -I\$(MYINC) -I\$(CLHEPINC) -I\$(MYINCLUDE)
F77_INCLUDE  = -Iinc -I\$(CLHEPINC) -I\$(MYINC)

# end Makefile.in
!
#
date 
echo "Makefile.in is done !" 
echo "Wait! -> installation.. It takes 3-10 minutes depending on CPU" 
echo "Check log file \"install.log\" "

sleep 1;
auxil/checkstatus.sh &
pidc=$!;

# start installation
cp -f auxil/Makefile Makefile
make -f Makefile > $installog 2>&1
# pid=$!;  wait $pid;


# get errors
MYERRORS=`grep -i "error" $installog`;
if [ -n "$MYERRORS" ]
then
  echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
  echo "There were errors in compilation of the Monte Carlo libraries"
  echo "check $installog" 
  echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
  echo "This could be uncorrectly installed ROOT or CLHEP library"
  echo "Check ROOT  as: cd $RUNMC/build/test; ./check_root.sh"
  echo "Check CLHEP as: cd $RUNMC/build/test; ./check_clhep.sh"
  echo "if by running these scripts you will see errors - reinstall these libraries"
  exit 1;
else
  echo "checking install.log  ->       looks ok";
fi
########
########
echo " "
echo "Messages:"
echo "  Be sure that acroread is installed"
echo "  Otherwise you cannot look at the help using RunMC GUI"
echo " "
echo "  For JAVA-based GUI (jrunmc), make sure that java is installed (type java -version)"
echo "  Check this by typing: java -version"
echo ""
echo "see installation log in \"install.log\" "
echo "make clean     - remove all object files"
echo "make cleanmc   - remove all object files for Monte Carlo models"
echo "make cleanall  - clean all above + binary files"
echo "make all       - compile (output on the screen, no any configuration checks" 
echo "install        - compile everything with checks. Output goes to install.log file"
echo "" 
echo "RunMC is installed: binary files in $RUNMC/bin"

# stop checking
# no pipe
# kill -9 $pidc > /dev/null;  
## remove pipes  
if [ -f $RUNMC"/build/auxil/check.pipe" ]
then
rm -f $RUNMC"/build/auxil/check.pipe"
fi
if [ -f $RUNMC"/build/auxil/install.tmp" ]
then
rm -f $RUNMC"/build/auxil/install.tmp" 
fi
##############

###############

exit 0

