C
C
      SUBROUTINE INPCS(IP,XM1,XM2,XM3,XM4)
C*********************************************************************
C
C     calculation of scaled input cross sections and slopes
C
C     input: IP               particle combination
C            XM1,XM2,XM3,XM4  masses of external lines
C            COMMON /GLOCMS/  energy and PT cut-off
C                   /REGGE/   soft and hard parameters
C                   /SIGMAS/  input cross sections
C                   /ZIGMAS/  scaled input values
C                    IFHARD   0  calculate hard input cross sections
C                             1  assume hard input cross sections exist
C
C     output: ZPOM            scaled pomeron cross section
C             ZIGR            scaled reggeon cross section
C             ZIGHR           scaled hard resolved cross section
C             ZIGHD           scaled hard direct cross section
C             ZIGT1           scaled triple-Pomeron cross section
C             ZIGT2           scaled triple-Pomeron cross section
C             ZIGL            scaled loop-Pomeron cross section
C
C*********************************************************************
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
C
      COMMON /HACONS/ PI,PI2,PI4,GEV2MB
C
      PARAMETER (NMAXD=100)
      COMMON /DEBUG/ IDEB(NMAXD),KSPOM,KHPOM,KSREG,KHDIR,KACCEP,
     &  KSTRG,KHTRG,KSLOO,KHLOO,KSDPO,KHDPO,KEVENT,KSOFT,KHARD
C
      PARAMETER ( MAXPRO = 16 )
      CHARACTER*18 PROC
      COMMON /PEPROC/ PROC(0:MAXPRO)
      COMPLEX*16      SIGP,SIGR,SIGHD,SIGHR,SIGT1,SIGT2,SIGL,SIGDP,
     &                SIGD1,SIGD2,DSIGH
      COMMON /SIGMAS/ SIGP,SIGR,SIGHD,SIGHR,SIGT1(2),SIGT2(2),SIGL,
     &                SIGDP(4),SIGD1(2),SIGD2(2),DSIGH(0:MAXPRO)
      COMPLEX*16      ZIGP,ZIGR,ZIGHD,ZIGHR,ZIGT1,ZIGT2,ZIGL,ZIGDP,
     &                ZIGD1,ZIGD2,
     &                BPOM,BREG,BHAR,BHAD,BTR1,BTR2,BLOO,BDP,BD1,BD2
      COMMON /ZIGMAS/ ZIGP,ZIGR,ZIGHD,ZIGHR,ZIGT1(2),ZIGT2(2),ZIGL,
     &                ZIGDP(4),ZIGD1(2),ZIGD2(2),
     &                BPOM,BREG,BHAR,BHAD,BTR1(2),BTR2(2),BLOO,BDP(4),
     &                BD1(2),BD2(2)
C
      COMMON /REGGE/  ALPOM,ALPOMP,GP(2),B0POM(2),
     &                ALREG,ALREGP,GR(2),B0REG(2),
     &                GPPP,GPPR,B0PPP,B0PPR,
     &                VDMFAC(4),VDMQ2F(4),B0HAR,AKFAC
      COMMON /TWOCHA/ PHISUP(2),RMASS1,RMASS2,VAR
C  CM system of Pomeron/Reggeon exchange
      COMMON /POMCMS/ ECMP,PCMP,PMASSP(2),PVIRTP(2),GAMBEP(4),
     &                SIDP,CODP,SIFP,COFP,NPOSP(2),
     &                IDPDG1,IDBAM1,IDPDG2,IDBAM2
      COMMON /CUTOFF/ PTCUT(4),CUTMU(4),FPS(4),FPH(4),PSOMIN,XSOMIN
      CHARACTER*8 MDLNA
      COMMON /MODELS/ MDLNA(50),ISWMDL(50),PARMDL(200),IPAMDL(200)
      PARAMETER ( MAXTAB = 20 )
      COMMON /HAXSEC/ XSECTA(4,-1:MAXPRO,4,MAXTAB),XSECT(6,-1:MAXPRO),
     &                MXSECT(0:4,-1:MAXPRO,4),ECMSH(4,MAXTAB),ISTTAB
      COMMON /FITMOD/ IFMOD,IFHARD
      COMMON /XSECPT/ SIGS,DSIGHP,SIGH,FS,FH,BETAS(3),AAS,PTCON
C
      COMPLEX*16      CZERO,BP4,BR4,BHR4,BHD4,BT14,BT24,BD4,SP,SR,SS,
     &                BPOM1,BPOM2,BREG1,BREG2,B0HARD
      DIMENSION       SCB1(4),SCB2(4),SCG1(4),SCG2(4)
      DIMENSION       BT14(2),BT24(2),BD4(4)
      DIMENSION       DSPT(0:MAXPRO)
C
      PARAMETER(ZERO=0.D0,
     &         IZERO=0,
     &          IONE=1,
     &          ITWO=2,
     &        ITHREE=3,
     &         IFOUR=4,
     &         IFIVE=5,
     &         OHALF=0.5D0,
     &           ONE=1.D0,
     &           TWO=2.D0,
     &         THREE=3.D0,
     &          FOUR=4.D0,
     &          FIVE=5.D0,
     &         THOUS=1.D3,
     &           EPS=0.01D0,
     &          DEPS=1.D-30)
C
      DATA  INIT /0/
C
      CDABS(SS) = ABS(SS)
      DCMPLX(X,Y) = CMPLX(X,Y)
C
      IF(INIT.EQ.IZERO) THEN
        CZERO=DCMPLX(ZERO,ZERO)
        INIT=IONE
      ENDIF
C  debug output
      IF(IDEB(48).GE.10) THEN
        WRITE(6,'(/1X,A,I3,4E12.3,I3)')
     &    'INPCS:DEBUG:IP,M1..M4,IFHARD',IP,XM1,XM2,XM3,XM4,IFHARD
      ENDIF
      CALL FITPAR(0)
C  scales
      CALL SCALES(XM1,XM2,XM3,XM4,SCALE1,SCALE2,SCALB1,SCALB2)
C
C  calculate hard input cross sections (output in mb)
      IF(IFHARD.NE.1) THEN
        IF((IFHARD.EQ.0).AND.(ECMSH(IP,1).GT.1.D0)) THEN
C  double-log interpolation
          CALL POHINT(IP,ECMP,0,MAXPRO,3,4,1)
          DO 60 M=0,15
            DSIGH(M) = XSECT(3,M)
            DSPT(M)  = XSECT(4,M)
 60       CONTINUE
        ELSE
C  new calculation
          CALL POHINT(IP,ECMP,0,-2,0,0,1)
          CALL POHXTO(ECMP,PTCUT(IP),PTCUT(IP),DSIGH,DSPT)
        ENDIF
C
C  save values to calculate soft pt distribution
        VFAC = (VDMQ2F(1)+VDMQ2F(2)
     &          +2.D0*PHISUP(1)*SQRT(VDMQ2F(1)*VDMQ2F(2)))
     &        *(VDMQ2F(3)+VDMQ2F(4)
     &          +2.D0*PHISUP(2)*SQRT(VDMQ2F(3)*VDMQ2F(4)))
        DSIGHP = DSPT(9)/VFAC
        SIGH   = DSIGH(9)/VFAC
C  extract real part
        IF(IPAMDL(1).EQ.IZERO) THEN
          DO 50 I=0,MAXPRO
            DSIGH(I)=DCMPLX(DREAL(DSIGH(I)),ZERO)
 50       CONTINUE
        ENDIF
C  write out results
        IF(IDEB(48).GE.15) THEN
          WRITE(6,'(/1X,A,E12.3)')
     &       'INPCS:DEBUG:QCD-PM CROSS SECTIONS (mb)',ECMP
          DO 200 I=0,MAXPRO
            WRITE(6,'(10X,A,2E14.4)') PROC(I),DSIGH(I)
 200      CONTINUE
        ENDIF
      ENDIF
C
      SCALE = CDABS(DSIGH(15))
      IF(SCALE.LT.DEPS) THEN
        SIGHD=CZERO
      ELSE
        SIGHD=DSIGH(15)
      ENDIF
      SCALE = CDABS(DSIGH(9))
      IF(SCALE.LT.DEPS) THEN
        SIGHR=CZERO
      ELSE
        SIGHR=DSIGH(9)*SCALE1*SCALE2/VFAC
      ENDIF
C
C  calculate soft input cross sections (output in mb)
      SS=DCMPLX(ECMP**2-PMASSP(1)**2-PMASSP(2)**2+0.01D0,ZERO)
      IF(IPAMDL(1).EQ.1) THEN
C  pomeron signature
        SP=SS*DCMPLX(ZERO,-ONE)
C  reggeon signature
        SR=SS*DCMPLX(ZERO,ONE)
      ELSE
        SP=SS
        SR=SS
      ENDIF
C  coupling constants (mb**1/2)
C  particle dependent slopes (GeV**-2)
      IF(IP.EQ.1) THEN
        GP1 = GP(1)
        GP2 = GP(2)
        GR1 = GR(1)
        GR2 = GR(2)
        B0POM1 = B0POM(1)
        B0POM2 = B0POM(2)
        B0REG1 = B0REG(1)
        B0REG2 = B0REG(2)
        B0HARD = B0HAR
      ELSE IF(IP.EQ.2) THEN
        GP1 = GP(1)
        GP2 = GPPP
        GR1 = GR(1)
        GR2 = GPPR
        B0POM1 = B0POM(1)
        B0POM2 = B0PPP
        B0REG1 = B0REG(1)
        B0REG2 = B0PPR
        B0HARD = B0POM1+B0POM2
      ELSE IF(IP.EQ.3) THEN
        GP1 = GPPP
        GP2 = GP(2)
        GR1 = GPPR
        GR2 = GR(2)
        B0POM1 = B0PPP
        B0POM2 = B0POM(2)
        B0REG1 = B0PPR
        B0REG2 = B0REG(2)
        B0HARD = B0POM1+B0POM2
      ELSE IF(IP.EQ.4) THEN
        GP1 = GPPP
        GP2 = GPPP
        GR1 = GPPR
        GR2 = GPPP
        B0POM1 = B0PPP
        B0POM2 = B0PPP
        B0REG1 = B0PPR
        B0REG2 = B0PPR
        B0HARD = B0POM1+B0POM2
      ELSE
        WRITE(6,'(/1X,A,I7)') 'INPCS:ERROR:INVALID IP',IP
        CALL POABRT
      ENDIF
      GP1 = GP1*SCALE1
      GP2 = GP2*SCALE2
      GR1 = GR1*SCALE1
      GR2 = GR2*SCALE2
C  input slope parameters (GeV**-2)
      BPOM1 = B0POM1*SCALB1
      BPOM2 = B0POM2*SCALB2
      BREG1 = B0REG1*SCALB1
      BREG2 = B0REG2*SCALB2
C  effective slopes
      SCALE = SS/((XM1**2+XM3**2)*(XM2**2+XM4**2))+TWO
      BPOM = BPOM1 + BPOM2 + ALPOMP*LOG(SCALE)
      BREG = BREG1 + BREG2 + ALREGP*LOG(SCALE)
      IF(IPAMDL(9).EQ.0) THEN
        BHAR = B0HARD
        BHAD = B0HARD
      ELSE IF(IPAMDL(9).EQ.1) THEN
        BHAR = B0HARD*(SCALB1+SCALB2)/TWO
        BHAD = BHAR
      ELSE IF(IPAMDL(9).EQ.2) THEN
        BHAR = BPOM1+BPOM2
        BHAD = BHAR
      ELSE
        BHAR = BPOM
        BHAD = BPOM
      ENDIF
C  input cross section pomeron
      SIGP=GP1*GP2*EXP((ALPOM-ONE)*LOG(SP))
      SIGR=GR1*GR2*EXP((ALREG-ONE)*LOG(SR))
C  save value to calculate soft pt distribution
      SIGS = (SIGR+SIGP)/(SCALE1*SCALE2)
C
C  higher order graphs
      VIRT1 = PVIRTP(1)
      VIRT2 = PVIRTP(2)
C  bare/renormalized intercept for enhanced graphs
      IF(IPAMDL(8).EQ.0) THEN
        DELTAP = ALPOM-ONE
      ELSE
        DELTAP = PARMDL(48)-ONE
      ENDIF
      SD = ECMP**2
      BP1 = 2.D0*BPOM1
      BP2 = 2.D0*BPOM2
C  input cross section high mass double diffraction
      CALL LOOREG(SD,GP1,BP1,GP2,BP2,
     &            DELTAP,ALPOMP,GPPP,B0PPP,VIRT1,VIRT2,SIGTR,BTR)
      SIGL = DCMPLX(SIGTR,ZERO)
      BLOO = DCMPLX(BTR,ZERO)
C
C  input cross section high mass diffraction particle 1
C  first possibility
      CALL SCALES(XM1,XM2,XM3,PMASSP(2),SCG1(1),SCG2(1),SCB1(1),SCB2(1))
      CALL SCALES(XM1,PMASSP(2),XM3,XM4,SCG1(2),SCG2(2),SCB1(2),SCB2(2))
      SCALB1 = (SCB1(1)+SCB1(2))/TWO
      SCALB2 = (SCB2(1)+SCB2(2))/TWO
      BP1 = 2.D0*BPOM1*SCALB1
      BP2 = 2.D0*BPOM2*SCALB2
C  input cross section high mass diffraction
      CALL TRIREG(SD,GP1,BP1,GP2,BP2,
     &            DELTAP,ALPOMP,GPPP,B0PPP,VIRT1,SIGTR,BTR)
      SIGT1(1) = SCG1(1)*SCG2(1)*SCG2(2)*DCMPLX(SIGTR,ZERO)
      BTR1(1)  = DCMPLX(BTR,ZERO)
C  second possibility:  high-low mass double diffraction
      CALL SCALES(XM1,XM2,XM3,RMASS2,SCG1(1),SCG2(1),SCB1(1),SCB2(1))
      CALL SCALES(XM1,RMASS2,XM3,XM4,SCG1(2),SCG2(2),SCB1(2),SCB2(2))
      SCALB1 = (SCB1(1)+SCB1(2))/TWO
      SCALB2 = (SCB2(1)+SCB2(2))/TWO
      BP1 = 2.D0*BPOM1*SCALB1
      BP2 = 2.D0*BPOM2*SCALB2
C  input cross section high mass diffraction
      CALL TRIREG(SD,GP1,BP1,GP2,BP2,
     &            DELTAP,ALPOMP,GPPP,B0PPP,VIRT1,SIGTR,BTR)
      SIGT1(2) = SCG1(1)*SCG2(1)*SCG2(2)*DCMPLX(SIGTR,ZERO)
      BTR1(2)  = DCMPLX(BTR,ZERO)
C
C  input cross section high mass diffraction particle 2
C  first possibility
      CALL SCALES(XM1,XM2,PMASSP(1),XM4,SCG1(1),SCG2(1),SCB1(1),SCB2(1))
      CALL SCALES(PMASSP(1),XM2,XM3,XM4,SCG1(2),SCG2(2),SCB1(2),SCB2(2))
      SCALB1 = (SCB1(1)+SCB1(2))/TWO
      SCALB2 = (SCB2(1)+SCB2(2))/TWO
      BP1 = 2.D0*BPOM1*SCALB1
      BP2 = 2.D0*BPOM2*SCALB2
C  input cross section high mass diffraction
      CALL TRIREG(SD,GP2,BP2,GP1,BP1,
     &            DELTAP,ALPOMP,GPPP,B0PPP,VIRT2,SIGTR,BTR)
      SIGT2(1) = SCG1(1)*SCG1(2)*SCG2(1)*DCMPLX(SIGTR,ZERO)
      BTR2(1)  = DCMPLX(BTR,ZERO)
C  second possibility:  high-low mass double diffraction
      CALL SCALES(XM1,XM2,RMASS1,XM4,SCG1(1),SCG2(1),SCB1(1),SCB2(1))
      CALL SCALES(RMASS1,XM2,XM3,XM4,SCG1(2),SCG2(2),SCB1(2),SCB2(2))
      SCALB1 = (SCB1(1)+SCB1(2))/TWO
      SCALB2 = (SCB2(1)+SCB2(2))/TWO
      BP1 = 2.D0*BPOM1*SCALB1
      BP2 = 2.D0*BPOM2*SCALB2
C  input cross section high mass diffraction
      CALL TRIREG(SD,GP2,BP2,GP1,BP1,
     &            DELTAP,ALPOMP,GPPP,B0PPP,VIRT2,SIGTR,BTR)
      SIGT2(2) = SCG1(1)*SCG1(2)*SCG2(1)*DCMPLX(SIGTR,ZERO)
      BTR2(2)  = DCMPLX(BTR,ZERO)
C
C  input cross section for X-iterated triple-Pomeron
C  first possibility
      CALL SCALES(XM1,XM2,PMASSP(1),XM4,SCG1(1),SCG2(1),SCB1(1),SCB2(1))
      CALL SCALES(PMASSP(1),XM2,XM3,XM4,SCG1(2),SCG2(2),SCB1(2),SCB2(2))
      CALL SCALES(XM1,XM2,XM3,PMASSP(2),SCG1(3),SCG2(3),SCB1(3),SCB2(3))
      CALL SCALES(XM1,PMASSP(2),XM3,XM4,SCG1(4),SCG2(4),SCB1(4),SCB2(4))
      SCALB1 = (SCB1(1)+SCB1(2)+SCB1(3)+SCB1(4))/FOUR
      SCALB2 = (SCB2(1)+SCB2(2)+SCB2(3)+SCB2(4))/FOUR
      BP1 = BPOM1*SCALB1
      BP2 = BPOM2*SCALB2
      CALL TRXPOM(SD,GP2,BP2,GP1,BP1,DELTAP,ALPOMP,GPPP,B0PPP,SIGTX,BTX)
      SIGDP(1) = SCG1(1)*SCG1(2)*SCG2(3)*SCG2(4)*DCMPLX(SIGTX,ZERO)
      BDP(1)   = DCMPLX(BTX,ZERO)
C  second possibility
      CALL SCALES(XM1,XM2,RMASS1,XM4,SCG1(1),SCG2(1),SCB1(1),SCB2(1))
      CALL SCALES(RMASS1,XM2,XM3,XM4,SCG1(2),SCG2(2),SCB1(2),SCB2(2))
      CALL SCALES(XM1,XM2,XM3,PMASSP(2),SCG1(3),SCG2(3),SCB1(3),SCB2(3))
      CALL SCALES(XM1,PMASSP(2),XM3,XM4,SCG1(4),SCG2(4),SCB1(4),SCB2(4))
      SCALB1 = (SCB1(1)+SCB1(2)+SCB1(3)+SCB1(4))/FOUR
      SCALB2 = (SCB2(1)+SCB2(2)+SCB2(3)+SCB2(4))/FOUR
      BP1 = BPOM1*SCALB1
      BP2 = BPOM2*SCALB2
      CALL TRXPOM(SD,GP2,BP2,GP1,BP1,DELTAP,ALPOMP,GPPP,B0PPP,SIGTX,BTX)
      SIGDP(2) = SCG1(1)*SCG1(2)*SCG2(3)*SCG2(4)*DCMPLX(SIGTX,ZERO)
      BDP(2)   = DCMPLX(BTX,ZERO)
C  third possibility
      CALL SCALES(XM1,XM2,PMASSP(1),XM4,SCG1(1),SCG2(1),SCB1(1),SCB2(1))
      CALL SCALES(PMASSP(1),XM2,XM3,XM4,SCG1(2),SCG2(2),SCB1(2),SCB2(2))
      CALL SCALES(XM1,XM2,XM3,RMASS2,SCG1(3),SCG2(3),SCB1(3),SCB2(3))
      CALL SCALES(XM1,RMASS2,XM3,XM4,SCG1(4),SCG2(4),SCB1(4),SCB2(4))
      SCALB1 = (SCB1(1)+SCB1(2)+SCB1(3)+SCB1(4))/FOUR
      SCALB2 = (SCB2(1)+SCB2(2)+SCB2(3)+SCB2(4))/FOUR
      BP1 = BPOM1*SCALB1
      BP2 = BPOM2*SCALB2
      CALL TRXPOM(SD,GP2,BP2,GP1,BP1,DELTAP,ALPOMP,GPPP,B0PPP,SIGTX,BTX)
      SIGDP(3) = SCG1(1)*SCG1(2)*SCG2(3)*SCG2(4)*DCMPLX(SIGTX,ZERO)
      BDP(3)   = DCMPLX(BTX,ZERO)
C  fourth possibility
      CALL SCALES(XM1,XM2,RMASS1,XM4,SCG1(1),SCG2(1),SCB1(1),SCB2(1))
      CALL SCALES(RMASS1,XM2,XM3,XM4,SCG1(2),SCG2(2),SCB1(2),SCB2(2))
      CALL SCALES(XM1,XM2,XM3,RMASS2,SCG1(3),SCG2(3),SCB1(3),SCB2(3))
      CALL SCALES(XM1,RMASS2,XM3,XM4,SCG1(4),SCG2(4),SCB1(4),SCB2(4))
      SCALB1 = (SCB1(1)+SCB1(2)+SCB1(3)+SCB1(4))/FOUR
      SCALB2 = (SCB2(1)+SCB2(2)+SCB2(3)+SCB2(4))/FOUR
      BP1 = BPOM1*SCALB1
      BP2 = BPOM2*SCALB2
      CALL TRXPOM(SD,GP2,BP2,GP1,BP1,DELTAP,ALPOMP,GPPP,B0PPP,SIGTX,BTX)
      SIGDP(4) = SCG1(1)*SCG1(2)*SCG2(3)*SCG2(4)*DCMPLX(SIGTX,ZERO)
      BDP(4)   = DCMPLX(BTX,ZERO)
C
C  input cross section for YY-iterated triple-Pomeron
C     .....
C
C  write out input cross sections
      IF(IDEB(48).GE.5) THEN
        WRITE(6,'(2(/1X,A))') 'INPUT CROSS SECTIONS AND SLOPES',
     &                        '==============================='
        WRITE(6,'(1X,A,3E12.3)') 'ENERGY                  ',ECMP,PVIRTP
        WRITE(6,'(1X,A,4E12.3)') 'EXTERNAL MASSES 1,2,3,4 ',
     &       XM1,XM2,XM3,XM4
        WRITE(6,'(A)') ' INPUT CROSS SECTIONS (millibarn):'
        WRITE(6,'(A,2E12.3)') '           SIGR     ',SIGR
        WRITE(6,'(A,2E12.3)') ' (soft)    SIGP     ',SIGP
        WRITE(6,'(A,2E12.3)') ' (hard)    SIGHR    ',SIGHR
        WRITE(6,'(A,2E12.3)') '           SIGHD    ',SIGHD
        WRITE(6,'(A,4E12.3)') '           SIGT1    ',SIGT1
        WRITE(6,'(A,4E12.3)') '           SIGT2    ',SIGT2
        WRITE(6,'(A,2E12.3)') '           SIGL     ',SIGL
        WRITE(6,'(A,4E12.3)') '         SIGDP(1-2) ',SIGDP(1),SIGDP(2)
        WRITE(6,'(A,4E12.3)') '         SIGDP(3-4) ',SIGDP(3),SIGDP(4)
        WRITE(6,'(A)') ' INPUT SLOPES (GeV**-2)'
        WRITE(6,'(A,2E12.3)') '           BREG     ',BREG
        WRITE(6,'(A,2E12.3)') '            BREG1   ',BREG1
        WRITE(6,'(A,2E12.3)') '            BREG2   ',BREG2
        WRITE(6,'(A,2E12.3)') '           BPOM     ',BPOM
        WRITE(6,'(A,2E12.3)') '            BPOM1   ',BPOM1
        WRITE(6,'(A,2E12.3)') '            BPOM2   ',BPOM2
        WRITE(6,'(A,2E12.3)') '           BHAR     ',BHAR
        WRITE(6,'(A,2E12.3)') '           BHAD     ',BHAD
        WRITE(6,'(A,E12.3)')  '           B0PPP    ',B0PPP
        WRITE(6,'(A,4E12.3)') '           BTR1     ',BTR1
        WRITE(6,'(A,4E12.3)') '           BTR2     ',BTR2
        WRITE(6,'(A,2E12.3)') '           BLOO     ',BLOO
        WRITE(6,'(A,4E12.3)') '           BDP(1-2) ',BDP(1),BDP(2)
        WRITE(6,'(A,4E12.3)') '           BDP(3-4) ',BDP(3),BDP(4)
      ENDIF
C
      BPOM  = BPOM*GEV2MB
      BREG  = BREG*GEV2MB
      BHAR  = BHAR*GEV2MB
      BHAD  = BHAD*GEV2MB
      BTR1(1)  = BTR1(1)*GEV2MB
      BTR1(2)  = BTR1(2)*GEV2MB
      BTR2(1)  = BTR2(1)*GEV2MB
      BTR2(2)  = BTR2(2)*GEV2MB
      BLOO  = BLOO*GEV2MB
C
      BP4 =BPOM*FOUR
      BR4 =BREG*FOUR
      BHR4=BHAR*FOUR
      BHD4=BHAD*FOUR
      BT14(1)=BTR1(1)*FOUR
      BT14(2)=BTR1(2)*FOUR
      BT24(1)=BTR2(1)*FOUR
      BT24(2)=BTR2(2)*FOUR
      BL4 =BLOO*FOUR
C
      ZIGP     = SIGP/(PI2*BP4)
      ZIGR     = SIGR/(PI2*BR4)
      ZIGHR    = SIGHR/(PI2*BHR4)*AKFAC
      ZIGHD    = SIGHD/(PI2*BHD4)*AKFAC
      ZIGT1(1) = SIGT1(1)/(PI2*BT14(1))
      ZIGT1(2) = SIGT1(2)/(PI2*BT14(2))
      ZIGT2(1) = SIGT2(1)/(PI2*BT24(1))
      ZIGT2(2) = SIGT2(2)/(PI2*BT24(2))
      ZIGL = SIGL/(PI2*BL4)
      DO 20 I=1,4
        BDP(I) = BDP(I)*GEV2MB
        BD4(I) = BDP(I)*FOUR
        ZIGDP(I) = SIGDP(I)/(PI2*BD4(I))
 20   CONTINUE
C
      IF(IDEB(48).GE.10) THEN
        WRITE(6,'(A)') ' NORMALIZED INPUT VALUES:'
        WRITE(6,'(A,2E12.3)') '           ZIGR ',ZIGR
        WRITE(6,'(A,2E12.3)') '           BREG ',BREG
        WRITE(6,'(A,2E12.3)') '           ZIGP ',ZIGP
        WRITE(6,'(A,2E12.3)') '           BPOM ',BPOM
        WRITE(6,'(A,2E12.3)') '          ZIGHR ',ZIGHR
        WRITE(6,'(A,2E12.3)') '           BHAR ',BHAR
        WRITE(6,'(A,2E12.3)') '          ZIGHD ',ZIGHD
        WRITE(6,'(A,2E12.3)') '           BHAD ',BHAD
        WRITE(6,'(A,4E12.3)') '          ZIGT1 ',ZIGT1
        WRITE(6,'(A,4E12.3)') '          ZIGT2 ',ZIGT2
        WRITE(6,'(A,2E12.3)') '           ZIGL ',ZIGL
        WRITE(6,'(A,4E12.3)') '     ZIGDP(1-2) ',ZIGDP(1),ZIGDP(2)
        WRITE(6,'(A,4E12.3)') '     ZIGDP(3-4) ',ZIGDP(3),ZIGDP(4)
      ENDIF
      END
