C
C
      SUBROUTINE PARTON(IPROC,JM1,JM2,P1,P2,IREJ)
C********************************************************************
C
C     calculation of complete parton configuration
C
C     input:  IPROC   process ID  1 nondiffractive
C                                 2 elastic
C                                 3 quasi-ela. rho,omega,phi prod.
C                                 4 double Pomeron
C                                 5 single diff 1
C                                 6 single diff 2
C                                 7 double diff diss.
C                                 8 direct photon
C             JM1,2   index of mother particles in /HEPEVS/
C
C
C     output: complete parton configuration in HEPEVS,HEPEVE
C             IREJ                1 failure
C                                 0 success
C                                50 rejection due to user cutoffs
C
C********************************************************************
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
C
      DIMENSION P1(4),P2(4)
C
      PARAMETER (ZERO   =  0.D0,
     &           ONE    =  1.D0,
     &           TWO    =  2.D0,
     &           OHALF  =  0.5D0,
     &           TINY   =  1.D-10)
C
      PARAMETER (NMAXD=100)
      COMMON /DEBUG/ IDEB(NMAXD),KSPOM,KHPOM,KSREG,KHDIR,KACCEP,
     &  KSTRG,KHTRG,KSLOO,KHLOO,KSDPO,KHDPO,KEVENT,KSOFT,KHARD
      COMMON /PROCES/ IPROCE,IDNODF,IDIFR1,IDIFR2,IDDPOM,IPRON(15)
C
      CHARACTER*8 MDLNA
      COMMON /MODELS/ MDLNA(50),ISWMDL(50),PARMDL(200),IPAMDL(200)
      COMMON /GLOCMS/ ECM,PCM,PMASS(2),PVIRT(2),IFPAP(2),IFPAB(2)
C
      PARAMETER (NMXJ=40)
      CHARACTER*10 REJTIT
      COMMON /REJSTA/ IFAIL(NMXJ),REJTIT(NMXJ)
C
C
      IREJ = 0
C  clear event statistics
      KSPOM = 0
      KHPOM = 0
      KSREG = 0
      KHDIR = 0
      KSTRG = 0
      KHTRG = 0
      KSLOO = 0
      KHLOO = 0
      KHARD = 0
      KSOFT = 0
      KSDPO = 0
      KHDPO = 0
C**********************************************************
C  nondiffractive resolved processes
      IF(IPROC.EQ.1) THEN
C  sample number of interactions
 555    CONTINUE
        IINT = 0
        IP   = 1
C  generate only hard events
        IF(ISWMDL(2).EQ.0) THEN
          MHPOM = 1
          MSPOM = 0
          MSREG = 0
          MHDIR = 0
        ELSE
C  minimum bias events
          CALL SAMPRB(ECM,IP,IINT,JINT,KINT,LINT,MINT)
          MINT = 0
          MHDIR = 0
C
C  resolved soft processes: pomeron and reggeon
          MSPOM = IINT
          MSREG = JINT
C  resolved hard process: hard pomeron
          MHPOM = KINT
C  resolved absorptive corrections
          MPTRI = LINT
          MPLOO = MINT
C  restrictions given by user
C  ----------------------------
          IF(ISWMDL(15).EQ.-1) THEN
            MHPOM = 0
            IF(MSREG.GT.0) THEN
              MSPOM = 0
              MSREG = 1
            ELSE
              MSPOM = 1
              MSREG = 0
            ENDIF
          ELSE IF(ISWMDL(15).EQ.0) THEN
            IF(MHPOM.GT.0) THEN
              MHPOM = 1
              MSPOM = 0
              MSREG = 0
            ELSE IF(MSPOM.GT.0) THEN
              MSPOM = 1
              MSREG = 0
            ELSE
              MSREG = 1
            ENDIF
          ELSE IF(ISWMDL(15).EQ.1) THEN
            MHPOM = MIN(1,MHPOM)
          ELSE IF(ISWMDL(15).EQ.2) THEN
            MSPOM = MIN(1,MSPOM)
          ENDIF
        ENDIF
C  ----------------------------
C
        KSPOM = MSPOM
        KSREG = MSREG
        KHPOM = MHPOM
        KHDIR = MHDIR
        KSTRG = MPTRI
        KSLOO = MPLOO
C  statistics
        ISPS = ISPS+KSPOM
        IHPS = IHPS+KHPOM
        ISRS = ISRS+KSREG
        ISTS = ISTS+KSTRG
        ISLS = ISLS+KSLOO
C  user limitations
        CALL PRESEL(10,IREJ)
        IF(IREJ.NE.0) RETURN
C
        IF(IDEB(3).GE.5) THEN
          WRITE(6,'(1X,A,I10,I7,6I4)')
     &      'PARTON:DEBUG:EV,SP,SR,HP,HD,ET,EL',
     &      KEVENT,MSPOM,MSREG,MHPOM,MHDIR,MPTRI,MPLOO
        ENDIF
        ITRY2 = 0
 50     CONTINUE
        ITRY2 = ITRY2+1
        IF(ITRY2.GT.1) CALL POHEPI(1,P1,P2,JM1,JM2)
        CALL STDPAR(JM1,JM2,MSPOM,MSREG,MHPOM,MHDIR,IREJ)
        IF(IREJ.NE.0) THEN
          IF(IREJ.EQ.50) RETURN
          IFAIL(2) = IFAIL(2) + 1
          IF(IDEB(3).GE.2) THEN
            WRITE(6,'(/1X,A,I5)')
     &        'PARTON:WARNING:REJECTION BY STDPAR ',ITRY2
            CALL POPREV(-1)
          ENDIF
          RETURN
        ENDIF
        IF(MHPOM.GT.0) THEN
          IDNODF = 3
        ELSE IF(MSPOM.GT.0) THEN
          IDNODF = 2
        ELSE
          IDNODF = 1
        ENDIF
C  check of quantum numbers of parton configurations
        IF(IDEB(3).GE.0) THEN
          CALL POQCHK(1,IREJ)
          IF(IREJ.NE.0) GOTO 50
        ENDIF
C  sample chains to prepare fragmentation
        CALL CHAINS(1,IREJ)
        IF(IREJ.NE.0) THEN
          IF(IREJ.EQ.50) RETURN
          IFAIL(30) = IFAIL(30)+1
          IF(IDEB(3).GE.2)  THEN
            WRITE(6,'(/1X,A,I5)')
     &        'PARTON:WARNING:REJECTION BY CHAINS',ITRY2
            CALL POPREV(-1)
          ENDIF
          IF(ITRY2.LT.20) GOTO 50
          IF(IDEB(3).GE.1) THEN
            WRITE(6,'(/1X,A,I5)')
     &        'PARTON:WARNING:REJECTION',ITRY2
            CALL POPREV(-1)
          ENDIF
          RETURN
        ENDIF
C  statistics
        ISPA = ISPA+KSPOM
        IHPA = IHPA+KHPOM
        ISRA = ISRA+KSREG
        ISTA = ISTA+KSTRG
        ISLA = ISLA+KSLOO
C
C**********************************************************
C  elastic scattering / quasi-elastic rho/omega/phi production
      ELSE IF((IPROC.EQ.2).OR.(IPROC.EQ.3)) THEN
        IF(IDEB(3).GE.5) THEN
          WRITE(6,'(1X,A,I10,I4)') 'PARTON:DEBUG:EV,QELAST. VMP',
     &      KEVENT,IPROC
        ENDIF
        CALL QELAST(IPROC,JM1,JM2,IREJ)
        IF(IREJ.NE.0) THEN
          IF(IDEB(3).GE.2) THEN
            WRITE(6,'(/1X,A,I5)')
     &        'PARTON:WARNING:REJECTION BY QELAST',IREJ
            CALL POPREV(-1)
          ENDIF
          RETURN
        ENDIF
C  prepare possible decays
        CALL CHAINS(1,IREJ)
        IF(IREJ.NE.0) THEN
          IF(IREJ.EQ.50) RETURN
          IFAIL(30) = IFAIL(30)+1
          RETURN
        ENDIF
C
C**********************************************************
C  double Pomeron scattering
      ELSE IF(IPROC.EQ.4) THEN
        MSOFT = 0
        MHARD = 0
        IF(IDEB(3).GE.5) WRITE(6,'(1X,A,I10)')
     &      'PARTON:DEBUG:EV,DOUBLE-POMERON SCATTERING',KEVENT
        IDPS = IDPS+1
        ITRY2 = 0
 60     CONTINUE
        ITRY2 = ITRY2+1
C  clear and write initial particles into HEPEVS
        IF(ITRY2.GT.1) CALL POHEPI(1,P1,P2,JM1,JM2)
        CALL PODBLE(JM1,JM2,MSOFT,MHARD,1,IREJ)
        IF(IREJ.NE.0) THEN
          IF(IDEB(3).GE.2) THEN
            WRITE(6,'(/1X,A,I5)')
     &        'PARTON:WARNING:REJECTION BY PODBLE',IREJ
            CALL POPREV(-1)
          ENDIF
          RETURN
        ENDIF
C  check of quantum numbers of parton configurations
        IF(IDEB(3).GE.0) THEN
          CALL POQCHK(1,IREJ)
          IF(IREJ.NE.0) GOTO 60
        ENDIF
C  sample chains to prepare fragmentation
        CALL CHAINS(1,IREJ)
        IF(IREJ.NE.0) THEN
          IF(IREJ.EQ.50) RETURN
          IFAIL(30) = IFAIL(30)+1
          IF(IDEB(3).GE.2) THEN
            WRITE(6,'(/1X,A,I5)')
     &        'PARTON:WARNING:REJECTION BY CHAINS',ITRY2
            CALL POPREV(-1)
          ENDIF
          IF(ITRY2.LT.10) GOTO 60
          WRITE(6,'(/1X,A,I5)') 'PARTON:WARNING:REJECTION',ITRY2
          CALL POPREV(-1)
          RETURN
        ENDIF
        IDPA = IDPA+1
C
C**********************************************************
C  single / double diffraction
      ELSE IF((IPROC.GE.5).AND.(IPROC.LE.7)) THEN
        MSOFT = 0
        MHARD = 0
        IF(IDEB(3).GE.5) THEN
          WRITE(6,'(1X,A,I10,2I4)')
     &      'PARTON:DEBUG:EV,DIFFRACTION',
     &      KEVENT,IPAR1,IPAR2
        ENDIF
        IF(IPROC.EQ.5) ID1S = ID1S+1
        IF(IPROC.EQ.6) ID2S = ID2S+1
        IF(IPROC.EQ.7) ID3S = ID3S+1
        ITRY2 = 0
 70     CONTINUE
        ITRY2 = ITRY2+1
        IPAR1 = 1
        IPAR2 = 1
        IF(IPROC.EQ.5) IPAR2 = 0
        IF(IPROC.EQ.6) IPAR1 = 0
C  clear and write initial particles into HEPEVS
        IF(ITRY2.GT.1) CALL POHEPI(1,P1,P2,JM1,JM2)
        CALL PODIFF(IPAR1,IPAR2,JM1,JM2,MSOFT,MHARD,0,IREJ)
        IF(IREJ.NE.0) THEN
          IF(IDEB(3).GE.2) THEN
            WRITE(6,'(/1X,A,I5)')
     &        'PARTON:WARNING:REJECTION BY PODIFF',IREJ
            CALL POPREV(-1)
          ENDIF
          RETURN
        ENDIF
C  check of quantum numbers of parton configurations
        IF(IDEB(3).GE.0) THEN
          CALL POQCHK(1,IREJ)
          IF(IREJ.NE.0) GOTO 70
        ENDIF
C  sample chains to prepare fragmentation
        CALL CHAINS(1,IREJ)
        IF(IREJ.NE.0) THEN
          IF(IREJ.EQ.50) RETURN
          IFAIL(30) = IFAIL(30)+1
          IF(IDEB(3).GE.2) THEN
            WRITE(6,'(/1X,A,I5)')
     &        'PARTON:WARNING:REJECTION BY CHAINS',ITRY2
            CALL POPREV(-1)
          ENDIF
          IF(ITRY2.LT.10) GOTO 70
          WRITE(6,'(/1X,A,I5)')
     &      'PARTON:WARNING:REJECTION',ITRY2
          CALL POPREV(-1)
          RETURN
        ENDIF
        IF(IPROC.EQ.5) ID1A = ID1A+1
        IF(IPROC.EQ.6) ID2A = ID2A+1
        IF(IPROC.EQ.7) ID3A = ID3A+1
C
C**********************************************************
C  single / double direct processes
      ELSE IF(IPROC.EQ.8) THEN
        MSREG = 0
        MSPOM = 0
        MHPOM = 0
        MHDIR = 1
        IF(IDEB(3).GE.5) THEN
          WRITE(6,'(1X,A,I10)') 'PARTON:DEBUG:EV,DIRECT PROC',KEVENT
        ENDIF
        KSPOM = MSPOM
        KSREG = MSREG
        KHPOM = MHPOM
        KHDIR = 4
        IDIS = IDIS+MHDIR
        ITRY2 = 0
 80     CONTINUE
        ITRY2 = ITRY2+1
C  clear and write initial particles into HEPEVS
        IF(ITRY2.GT.1) CALL POHEPI(1,P1,P2,JM1,JM2)
        CALL STDPAR(JM1,JM2,MSPOM,MSREG,MHPOM,MHDIR,IREJ)
        IF(IREJ.NE.0) THEN
          IF(IREJ.EQ.50) RETURN
          IFAIL(2) = IFAIL(2) + 1
          IF(IDEB(3).GE.2) THEN
            WRITE(6,'(/1X,A,I5)')
     &        'PARTON:WARNING:REJECTION BY STDPAR',ITRY2
            CALL POPREV(-1)
          ENDIF
          RETURN
        ENDIF
        IDNODF = 4
C  check of quantum numbers of parton configurations
        IF(IDEB(3).GE.0) THEN
          CALL POQCHK(1,IREJ)
          IF(IREJ.NE.0) GOTO 80
        ENDIF
C  sample chains to prepare fragmentation
        CALL CHAINS(1,IREJ)
        IF(IREJ.NE.0) THEN
          IF(IREJ.EQ.50) RETURN
          IFAIL(30) = IFAIL(30)+1
          IF(IDEB(3).GE.2) THEN
            WRITE(6,'(/1X,A,I5)') 
     &        'PARTON:WARNING:REJECTION BY CHAINS',ITRY2
            CALL POPREV(-1)
          ENDIF
          IF(ITRY2.LT.10) GOTO 80
          WRITE(6,'(/1X,A,I5)') 'PARTON:WARNING:REJECTION',ITRY2
          CALL POPREV(-1)
          RETURN
        ENDIF
        IF(IPROC.EQ.5) ID1A = ID1A+1
        IF(IPROC.EQ.6) ID2A = ID2A+1
        IF(IPROC.EQ.7) ID3A = ID3A+1
        IDIA = IDIA+MHDIR
C
C**********************************************************
C  initialize control statistics
      ELSE IF(IPROC.EQ.-1) THEN
        CALL SAMPRB(ECM,-1,0,0,0,0,0)
        CALL STDPAR(-1,0,0,0,0,0,IREJ)
        CALL SEAFLA(-1,0,0,DUMMY)
        IF((IFPAP(1).EQ.22).OR.(IFPAP(2).EQ.22)) CALL QELAST(-1,1,2,0)
        ISPS = 0
        ISPA = 0
        ISRS = 0
        ISRA = 0
        IHPS = 0
        IHPA = 0
        ISTS = 0
        ISTA = 0
        ISLS = 0
        ISLA = 0
        ID1S = 0
        ID1A = 0
        ID2S = 0
        ID2A = 0
        ID3S = 0
        ID3A = 0
        IDPS = 0
        IDPA = 0
        IDIS = 0
        IDIA = 0
        CALL CHAINS(-1,IREJ)
        CALL PODIFF(0,0,0,0,0,0,-1,IREJ)
        RETURN
C
C  produce statistics summary
      ELSE IF(IPROC.EQ.-2) THEN
        IF(ISWMDL(2).NE.0) CALL SAMPRB(ECM,-2,0,0,0,0,0)
        IF(IDEB(3).GE.0) THEN
          WRITE(6,'(/1X,A,/1X,A)')
     &      'PARTON:DEBUG:ACCEPTED PARTON CONFIGURATIONS:',
     &      '============================================'
          WRITE(6,'(10X,A)') 'PROCESS          SAMPLED      ACCEPTED'
          WRITE(6,'(10X,A,2I12)') 'SOFT POM.',ISPS,ISPA
          WRITE(6,'(10X,A,2I12)') 'HARD POM.',IHPS,IHPA
          WRITE(6,'(10X,A,2I12)') 'SOFT REG.',ISRS,ISRA
          WRITE(6,'(10X,A,2I12)') 'ENH. TRI.',ISTS,ISTA
          WRITE(6,'(10X,A,2I12)') 'ENH. LOO.',ISLS,ISLA
          WRITE(6,'(10X,A,2I12)') 'DIFF.PA1.',ID1S,ID1A
          WRITE(6,'(10X,A,2I12)') 'DIFF.PA2.',ID2S,ID2A
          WRITE(6,'(10X,A,2I12)') 'DOUB.DIF.',ID3S,ID3A
          WRITE(6,'(10X,A,2I12)') 'DOUB.POM.',IDPS,IDPA
          WRITE(6,'(10X,A,2I12/)') 'DIR.PHOT.',IDIS,IDIA
        ENDIF
        CALL STDPAR(-2,0,0,0,0,0,IREJ)
        IF((IFPAP(1).EQ.22).OR.(IFPAP(2).EQ.22)) CALL QELAST(-2,1,2,0)
        CALL CHAINS(-2,IREJ)
        CALL PODIFF(0,0,0,0,0,0,-2,IREJ)
        CALL SEAFLA(-2,0,0,DUMMY)
        RETURN
      ELSE
        WRITE(6,'(1X,A,I2)')
     &    'PARTON:ERROR:UNKNOWN PROCESS ID ',IPROC
        STOP
      ENDIF
      END
