C
C
      SUBROUTINE POHXTO(ECMH,PTCUTR,PTCUTD,DSIGMC,DSDPTC)
C**********************************************************************
C
C     total hard cross section (perturbative QCD, Parton Model)
C
C     input:  ECMH     CMS energy of scattering system
C             PTCUTR   PT cutoff for resolved processes
C             PTCUTD   PT cutoff for direct processes (photon, Pomeron)
C
C     output: DSIGMC(0:12) QCD PM cross sections for given cutoff
C             DSDPTC(0:12) QCD PM differential cross sections at cutoff
C
C     note:  COMPLEX*16          DSIGMC
C            DOUBLE PRECISION    DSDPTC
C
C**********************************************************************
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
C
      PARAMETER ( MAXPRO = 16 )
      COMPLEX*16 DSIGMC
      DIMENSION DSIGMC(0:MAXPRO),DSDPTC(0:MAXPRO)
      CHARACTER*8 MDLNA
      COMMON /MODELS/ MDLNA(50),ISWMDL(50),PARMDL(200),IPAMDL(200)
C  CM system of Pomeron/Reggeon exchange
      COMMON /POMCMS/ ECMP,PCMP,PMASSP(2),PVIRTP(2),GAMBEP(4),
     &                SIDP,CODP,SIFP,COFP,NPOSP(2),
     &                IDPDG1,IDBAM1,IDPDG2,IDBAM2
      COMMON /HACONS/ PI,PI2,PI4,GEV2MB
      COMMON /HAGAUP/ NGAUP1,NGAUP2,NGAUET,NGAUIN,NGAUSO
      COMMON /HADRON/ QMASS(6),BET,PCOUDI,PNORM,VALPRG(2),NFS
      COMMON /HAPARA/ ALPHAS,Q0SQR,ALASQR,BQCD,NPD,NF,NHA,NHB
      COMMON /XSECPT/ SIGS,DSIGHP,SIGH,FS,FH,BETAS(3),AAS,PTCON
      COMPLEX*16 DSIG1
      DIMENSION DSIG1(0:MAXPRO)
      DIMENSION ABSZ(32),WEIG(32)
**sr 29.04. commented to use dp-JETSET
      REAL ULALEM,SSR
**
      DATA FAC / 3.0D0 /
C
      DO 10 M=0,MAXPRO
        DSIGMC(M)= CMPLX(0.D0,0.D0)
 10   CONTINUE
      EEC=ECMH/2.D0
C
      IF ( PTCUTR.GE.EEC ) GOTO 100
C
C  integration for resolved processes
      PTMIN  = PTCUTR
      PTMAX  = MIN(FAC*PTMIN,EEC)
      NPOINT = NGAUP1
      CALL POHXPT(ECMH,PTMIN,1,DSIG1)
      DO 60 M=1,9
        DSDPTC(M) = DREAL(DSIG1(M))
 60   CONTINUE
      DSIGH   = DREAL(DSIG1(9))
      DSIGHP  = DSIGH
      PTMXX  = 0.95D0*PTMAX
      CALL POHXPT(ECMH,PTMXX,1,DSIG1)
      DSIGL  = DREAL(DSIG1(9))
      EX     = LOG(DSIGH/(DSIGL+1.D-30))/LOG(FAC)
      EX1    = 1.0D0-EX
      DO 50 K=1,2
        IF ( PTMIN.GE.PTMAX ) GOTO 40
        RL   = PTMIN**EX1
        RU   = PTMAX**EX1
        CALL GSET(RL,RU,NPOINT,ABSZ,WEIG)
        DO 30 I=1,NPOINT
          R  = ABSZ(I)
          PT = R**(1.0D0/EX1)
          CALL POHXPT(ECMH,PT,1,DSIG1)
          F  = WEIG(I)*PT/(R*EX1)
          DO 20 M=1,9
            DSIGMC(M) = DSIGMC(M)+F*DSIG1(M)
 20       CONTINUE
 30     CONTINUE
 40     PTMIN  = PTMAX
        PTMAX  = EEC
        NPOINT = NGAUP2
 50   CONTINUE
      SIGH = DREAL(DSIGMC(9))
 100  CONTINUE
C
C  integration for direct processes
      IF(PTCUTD.GE.ECMH/2.D0) RETURN
C
      IF((IDPDG1.EQ.22).OR.(IDPDG1.EQ.45)
     &   .OR.(IDPDG2.EQ.22).OR.(IDPDG2.EQ.45)) THEN
        PTMIN  = PTCUTD
        PTMAX  = MIN(FAC*PTMIN,EEC)
        NPOINT = NGAUP1
        CALL POHXPT(ECMH,PTMIN,2,DSIG1)
        DO 160 M=10,16
          DSDPTC(M) = DREAL(DSIG1(M))
 160    CONTINUE
        DSIGH   = DREAL(DSIG1(15)-DSIG1(14))
        PTMXX  = 0.95D0*PTMAX
        CALL POHXPT(ECMH,PTMXX,2,DSIG1)
        DSIGL  = DREAL(DSIG1(15)-DSIG1(14))
        IF(DSIGH.EQ.DSIGL) RETURN
        EX     = LOG(DSIGH/(DSIGL+1.D-30))/LOG(FAC)
        EX1    = 1.0D0-EX
        DO 150 K=1,2
          IF ( PTMIN.GE.PTMAX ) GOTO 140
          RL   = PTMIN**EX1
          RU   = PTMAX**EX1
          CALL GSET(RL,RU,NPOINT,ABSZ,WEIG)
          DO 130 I=1,NPOINT
            R  = ABSZ(I)
            PT = R**(1.0D0/EX1)
            CALL POHXPT(ECMH,PT,2,DSIG1)
            F  = WEIG(I)*PT/(R*EX1)
            DO 120 M=10,15
              DSIGMC(M) = DSIGMC(M)+F*DSIG1(M)
 120        CONTINUE
 130      CONTINUE
 140      PTMIN  = PTMAX
          PTMAX  = EEC
          NPOINT = NGAUP2
 150    CONTINUE
      ENDIF
C
C  double direct process
      IF(((IDPDG1.EQ.22).OR.(IDPDG1.EQ.45))
     &   .AND.((IDPDG2.EQ.22).OR.(IDPDG2.EQ.45))) THEN
        FACC = 0.D0
        SS = ECMH*ECMH
        SSR = REAL(SS)
        ALPHAE = DBLE(ULALEM(SSR))
*       ALPHAE = 1.D0/137.D0
        DO 300 I=1,NF
          IF(IDPDG1.EQ.22) THEN
            F1 = (4.D0-3.D0*MOD(I,2))/9.D0*ALPHAE
          ELSE
            F1 = PARMDL(74)
          ENDIF
          IF(IDPDG2.EQ.22) THEN
            F2 = (4.D0-3.D0*MOD(I,2))/9.D0*ALPHAE
          ELSE
            F2 = PARMDL(74)
          ENDIF
          FACC = FACC + F1*F2*3.D0
 300    CONTINUE
C
        ZZ = SQRT(1.D0-4.D0*PTCUTD*PTCUTD/SS)
        R  = 4.D0*PI/SS*(LOG((1.D0+ZZ)/(1.D0-ZZ))-ZZ)*GEV2MB
C  hadronic cross section
        DSIGMC(14) = R*FACC
C************************** 1.04 bug? ****************
*       SS = ECMH*ECMH
*       ZZ = 4.D0*PTCUTD*PTCUTD/SS
*       ZZ = 6.D0*GEV2MB*FACC*PI/SS/3.D0/(ALPHAE*137.D0)**2
*    &     *(4.D0*LOG((1.D0+SQRT(1.D0-ZZ))/SQRT(ZZ))-2.D0*SQRT(2.D0-ZZ))
*       ZZ = MAX(ZZ,0.D0)
*       write(6,'(1x,a,3e12.4)')
*    &    'ecm,old/new',ECMH,ZZ,DREAL(DSIGMC(14))
C******************************************************
C  leptonic cross section
        IF((IDPDG1.EQ.22).AND.(IDPDG2.EQ.22)) THEN
          DSIGMC(16) = R*3.D0*ALPHAE**2
C  simulation of tau together with quarks
          IF(IPAMDL(64).NE.0) DSIGMC(14) = DSIGMC(14)+DSIGMC(16)/3.D0
          DSIGMC(16) = DSIGMC(16)*2.D0/3.D0
        ELSE
          DSIGMC(16) = CMPLX(0.D0,0.D0)
        ENDIF
C  sum of direct part
        DSIGMC(15) = CMPLX(0.D0,0.D0)
        DO 400 I=10,14
          DSIGMC(15) = DSIGMC(15) + DSIGMC(I)
 400    CONTINUE
      ENDIF
C
      DSIGMC(0) = DSIGMC(9) + DSIGMC(15)
      DSDPTC(0) = DSDPTC(9) + DSDPTC(15)
      END
