C
C
      SUBROUTINE SAMPRO(IPROC)
C********************************************************************
C
C     routine to sample kind of process
C
C     input:   IPROC
C                 -2     output of statistics
C                 -1     initialization
C                  0     sampling of process
C     output:  IPROC
C                  1     nondiffractive resolved process
C                  2     elastic scattering
C                  3     quasi elastic rho/omega/phi production
C                  4     central diffraction
C                  5     single diffraction according to IDIFF1
C                  6     single diffraction according to IDIFF2
C                  7     double diffraction
C                  8     direct processes
C
C********************************************************************
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
C
      PARAMETER (ZERO   =  0.D0,
     &           ONE    =  1.D0,
     &           TWO    =  2.D0,
     &           OHALF  =  0.5D0,
     &           EPS    =  1.D-6,
     &           TINY   =  1.D-10)
      PARAMETER (NMAXD=100)
      COMMON /DEBUG/ IDEB(NMAXD),KSPOM,KHPOM,KSREG,KHDIR,KACCEP,
     &  KSTRG,KHTRG,KSLOO,KHLOO,KSDPO,KHDPO,KEVENT,KSOFT,KHARD
      COMMON /GLOCMS/ ECM,PCM,PMASS(2),PVIRT(2),IFPAP(2),IFPAB(2)
      COMMON /HADVAL/ ECMN,PCMN,SECM,SPCM,XPSUB,XTSUB,
     &                IDEQP(2),IDEQB(2),IHFLD(2,2),IHFLS(2)
C
      COMMON /XSECTP/ SIGTOT,SIGELA,SIGVM(0:4,0:4),SIGINE,SIGDIR,
     &                SIGLSD(2),SIGHSD(2),SIGLDD,SIGHDD,SIGCDF,
     &                SIGPOM,SIGREG,SIGHAR,SIGTR1,SIGTR2,SIGLOO,SIGDPO,
     &                SIG1SO,SIG1HA,SLOEL,SLOVM(4,4),SIGGEN(4),
     &                FSUP(2)
C
      COMMON /PROCES/ IPROCE,IDNODF,IDIFR1,IDIFR2,IDDPOM,IPRON(15)
      CHARACTER*8 MDLNA
      COMMON /MODELS/ MDLNA(50),ISWMDL(50),PARMDL(200),IPAMDL(200)
C
      DIMENSION PRO(8),PAC(8),XPROB(8),SIGSDI(2)
C
C  initialization of statistics
      IF(IPROC.GE.0) THEN
        CALLS      = CALLS + ONE
C  probabilities
        IF(ISWMDL(1).EQ.3) THEN
          IF(ISWMDL(2).EQ.1) THEN
            SIGSDI(1) = SIGLSD(1)+SIGHSD(1)
            SIGSDI(2) = SIGLSD(2)+SIGHSD(2)
            SIGDDI    = SIGLDD+SIGHDD
            SIGNDR    = SIGINE-SIGVM(0,0)-SIGCDF-SIGDIR
     &                - SIGSDI(1)-SIGSDI(2)-SIGDDI
            XPROB(1)  = SIGNDR/SIGTOT
            XPROB(2)  = SIGELA/SIGTOT
            XPROB(3)  = SIGVM(0,0)/SIGTOT
            XPROB(4)  = SIGCDF/SIGTOT
            XPROB(5)  = SIGSDI(1)/SIGTOT
            XPROB(6)  = SIGSDI(2)/SIGTOT
            XPROB(7)  = SIGDDI/SIGTOT
            XPROB(8)  = SIGDIR/SIGTOT
          ELSE
            SIGHR = ZERO
            IF(IPRON(1).EQ.1) SIGHR = SIGHAR
            SIGHD = ZERO
            IF(IPRON(8).EQ.1) SIGHD = SIGDIR
            XPROB(1) = SIGHR/(SIGHR+SIGHD)
            XPROB(2) = ZERO
            XPROB(3) = ZERO
            XPROB(4) = ZERO
            XPROB(5) = ZERO
            XPROB(6) = ZERO
            XPROB(7) = ZERO
            XPROB(8) = SIGHD/(SIGHR+SIGHD)
          ENDIF
        ELSE
          WRITE(6,'(/,1X,A,I4)') 'SAMPRO:ERROR:UNSUPPORTED MODEL',
     &      ISWMDL(1)
          CALL POABRT
        ENDIF
C  culumnative values
        DO 230 I=2,8
          XPROB(I) = XPROB(I-1)+XPROB(I)
 230    CONTINUE
        IF(IDEB(11).GE.10) THEN
          WRITE(6,'(/,1X,A)') 'SAMPRO:DEBUG:SUMMED PROB.DISTRIBUTION'
          DO 240 I=1,8
            WRITE(6,'(5X,I3,2X,1PE12.4)') I,XPROB(I)
 240      CONTINUE
        ENDIF
        IF((ABS(XPROB(8)-ONE).GT.1.D-2).AND.(IDEB(11).GE.0)) THEN
          FAC = ONE/XPROB(8)
          WRITE(6,'(/1X,A,1PE12.3)')
     &      'SAMPRO:WARNING:INCONSISTENT CROSS SECTIONS, RESCALING',FAC
        ENDIF
C
C  sample process
 50     CONTINUE
          XI = RNDM(SIGSUM)*XPROB(8)
          DO 100 I=1,8
            IF(XI.LE.XPROB(I)) GOTO 110
 100      CONTINUE
 110      CONTINUE
          IPROC = MIN(I,8)
C
          PITER      = PITER + ONE
          PRO(IPROC) = PRO(IPROC) + ONE
          IF(ISWMDL(2).EQ.1) THEN
            SIGSUM = SIGSUM+SIGTOT
          ELSE
            SIGSUM = SIGSUM+SIGGEN(3)
          ENDIF
C  reject certain processes
        IF(IPRON(IPROC).EQ.0) GOTO 50
        PAC(IPROC) = PAC(IPROC) + ONE
        ECMSUM = ECMSUM + ECM
C  debug output
        IF(IDEB(11).GT.0) 
     &    WRITE(6,'(1X,A,I4)') 'SAMPRO:DEBUG:PROCESS-ID',IPROC
C
C  statistics initialization
      ELSE IF(IPROC.EQ.-1) THEN
        DO 250 I=1,8
          PRO(I) = ZERO
          PAC(I) = ZERO
 250    CONTINUE
        CALLS = ZERO
        PITER = ZERO
        SIGSUM = ZERO
        ECMSUM = ZERO
C
C  write out statistics
      ELSE IF(IPROC.EQ.-2) THEN
        SIGSUM = SIGSUM/PITER**2
        ECMSUM = ECMSUM/CALLS
        IF(IDEB(11).GE.0) THEN
          WRITE(6,'(/,1X,A,F12.0,1PE12.3,/,1X,A)')
     &      'SAMPRO:PROCESS STATISTICS (CALLS,ENERGY)',CALLS,ECMSUM,
     &      '========================='
          WRITE(6,'(8X,A)')
     &          'PROCESS      TRIED     CROSS SECTION   ACCEPTED'
          IF(ISWMDL(2).EQ.1) THEn
            WRITE(6,'(9(/5X,A,F12.0,5X,1PE12.3,5X,0PF12.0))')
     &        '    ALL PROCESSES',PITER,PITER*SIGSUM,CALLS,
     &        ' NONDIF.INELASTIC',PRO(1),PRO(1)*SIGSUM,PAC(1),
     &        '          ELASTIC',PRO(2),PRO(2)*SIGSUM,PAC(2),
     &        'VMESON PRODUCTION',PRO(3),PRO(3)*SIGSUM,PAC(3),
     &        '   DOUBLE POMERON',PRO(4),PRO(4)*SIGSUM,PAC(4),
     &        ' SINGLE DIFFR.(1)',PRO(5),PRO(5)*SIGSUM,PAC(5),
     &        ' SINGLE DIFFR.(2)',PRO(6),PRO(6)*SIGSUM,PAC(6),
     &        ' DOUBLE DIFFRACT.',PRO(7),PRO(7)*SIGSUM,PAC(7),
     &        ' DIRECT PROCESSES',PRO(8),PRO(8)*SIGSUM,PAC(8)
          ELSE
            WRITE(6,'(3(/5X,A,F12.0,5X,1PE12.3,5X,0PF12.0))')
     &        '    ALL PROCESSES',PITER,PITER*SIGSUM,CALLS,
     &        '  DOUBLE RESOLVED',PRO(1),PRO(1)*SIGSUM,PAC(1),
     &        ' SINGLE RES + DIR',PRO(8),PRO(8)*SIGSUM,PAC(8)
            ENDIF
        ENDIF
      ENDIF
      END
