C
C
      DOUBLE PRECISION FUNCTION XSLOPE(TMIN,TMAX,XM1,XM2,IREJ)
C**********************************************************************
C
C     sampling of T  (Mandelstam variable) distribution within
C              limits TMIN, TMAX
C
C     input:    TMIN,TMAX ( < 0 )   limitations (GeV**2)
C               XM1                 mass of diffractive system 1
C               XM2                 mass of diffractive system 2
C
C     output:   T value    ( < 0 )  (GeV**2)
C               IREJ       0  successful sampling
C                          1  masses too big for given T range
C
C**********************************************************************
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      SAVE
C
      PARAMETER (NMAXD=100)
      COMMON /DEBUG/ IDEB(NMAXD),KSPOM,KHPOM,KSREG,KHDIR,KACCEP,
     &  KSTRG,KHTRG,KSLOO,KHLOO,KSDPO,KHDPO,KEVENT,KSOFT,KHARD
C
      CHARACTER*8 MDLNA
      COMMON /MODELS/ MDLNA(50),ISWMDL(50),PARMDL(200),IPAMDL(200)
C
      PARAMETER (NMXJ=40)
      CHARACTER*10 REJTIT
      COMMON /REJSTA/ IFAIL(NMXJ),REJTIT(NMXJ)
C  CM system of diffraction
      COMMON /DIFCMS/ ECMD,PCMD,PMASSD(2),PVIRTD(2),GAMBED(4),
     &                SIDD,CODD,SIFD,COFD,PDCMS(4,2),NPOSD(2)
      COMMON /REGGE/  ALPOM,ALPOMP,GP(2),B0POM(2),
     &                ALREG,ALREGP,GR(2),B0REG(2),
     &                GPPP,GPPR,B0PPP,B0PPR,
     &                VDMFAC(4),VDMQ2F(4),B0HAR,AKFAC
      COMMON /TWOCHA/ PHISUP(2),RMASS1,RMASS2,VAR
C
      PARAMETER(EPS  = 1.D-10,
     &          IONE = 1,
     &          TWO  = 2.D0,
     &          PI   = 3.14159265359D0,
     &          PI2  = 6.28318530718D0,
     &          ZERO = 0.D0)
C
      IREJ = 0
      XMP12 = XM1**2+PVIRTD(1)
      XMP22 = XM2**2+PVIRTD(2)
      XMX1 = SQRT(XMP12)
      XMX2 = SQRT(XMP22)
      SS = ECMD**2
C
C  calculation of slope (mass dependent)
      CALL SCALES(PMASSD(1),PMASSD(2),XMX1,XMX2,SC1,SC2,SB1,SB2)
      FAC = 4.D0*(PMASSD(1)*PMASSD(2))**2
      SLOPE = B0PPP+TWO*(B0POM(1)*SB1+B0POM(2)*SB2+ALPOMP*LOG(SS*FAC
     &  /((PMASSD(1)**2+XMP12)*(PMASSD(2)**2+XMP22))+PARMDL(47)))
      SLOPE = MAX(SLOPE,2.D0)
C
C  determine min. ABS(T) necessary to produce masses
      PCM2 = PCMD**2
      PCMP2 = XLAMB(SS,XMP12,XMP22)**2/(4.D0*SS)
      IF(PCMP2.LE.ZERO) THEN
        IREJ = 1
        XSLOPE = 0.D0
        RETURN
      ENDIF
      TMINP = PMASSD(1)**2+XMP12+TWO*PCMD*SQRT(PCMP2)
     &        -TWO*SQRT((PMASSD(1)**2+PCM2)*(XMP12+PCMP2))
C
      IF(TMINP.LT.TMAX) THEN
        IF(IDEB(44).GE.3) THEN
          WRITE(6,'(1X,A,/5X,5E12.3)')
     &      'XSLOPE:REJECTION:TMIN,TMAX,TMINP,XM1,XM2',
     &      TMIN,TMAX,TMINP,XM1,XM2
        ENDIF
        IFAIL(32) = IFAIL(32)+1
        IREJ = 1
        XSLOPE = 0.D0
        RETURN
      ENDIF
      TMINA = MIN(TMIN,TMINP)
C
C  sampling from corrected range of T
      TMINE = EXP(SLOPE*TMINA)
      TMAXE = EXP(SLOPE*TMAX)
      XI = (TMINE-TMAXE)*RNDM(SLOPE)+TMAXE
      TT = LOG(XI)/SLOPE
C  debug output
      IF(IDEB(44).GE.15) THEN
        WRITE(6,'(1X,A,/5X,7E10.3)')
     &    'XSLOPE:DEBUG:TMIN,TMINP,TMAX,SLOPE,T,XM1,XM2',
     &    TMIN,TMINP,TMAX,SLOPE,TT,XM1,XM2
      ENDIF
C
      XSLOPE = TT
      END
