/* This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/



//Javac.java - this class runs the Java compiler by passing arguments
//to the process class
//(C)2000-2001 Mark Beynon
//mark@jpedit.co.uk
//http://www.jpedit.co.uk

package com.javac;

import javax.swing.JTextArea;

import java.io.File;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.BufferedReader;

import javax.swing.text.Element;
import javax.swing.text.Segment;
import javax.swing.text.Position;

import com.jpe.jpe;
import com.utils.*;




public class Javac implements Runnable
{


	private jpe win;
	private Utils Utils = new Utils(win);
	private String fileSep = System.getProperty("file.separator");
	private boolean dirty, javacerror = false;
  private Thread thread;
  private String g;
  private String classpath;
  private String Options;
  private String jdk;


	public Javac(jpe win, String g, String classpath, String Options, String jdk)
	{
		super();
		this.win       = win;
		this.g         = g;
		this.classpath = classpath;
		this.Options   = Options;
		this.jdk       = jdk;

	}

	public void run()
	{
    run(g, classpath, Options, jdk);
  }

  private void killThread()
  {
		win.stopJavacThread();
	}

	public void run(String g, String classpath, String Options, String jdk)
	{

		String line = new String();
	  InputStreamReader inp;
		BufferedReader bufred;
		String gap = " ";
		JTextArea jtacomp = new JTextArea();
		Process ps = null;

		if((g == null)|| (g == ""))
		{
			Utils.userMessage("Warning", "Please save file", 1);
			win.save();
			g = win.getFileName();
			//return;
		}

		if(jdk == null)
		{
			Utils.userMessage("Warning", "Please specify JDK path", 1);
			win.setJavaHome();
			jdk = win.getJDK();
			//return;
		}

		if(Options == null)
		{
			Utils.userMessage("Warning", "Please specify Compiler Options", 1);
			win.JavacOptions();
			Options = win.getJavacOptions();
			//return;
		}

		if(classpath == null)
		{
			Utils.userMessage("Warning", "Please specify classpath", 1);
			win.JavacOptions();
			classpath = win.getClasspath();
			//return;
		}


		if ((jdk != null) && (Options != null) && (g != null))
		{

			try
			{

				Utils.userMessage("Warning", jdk + fileSep +"javac.exe" + gap + "-classpath " + gap + classpath + gap + Options + gap + g, 1);

				ps = Runtime.getRuntime().exec(jdk + fileSep +"javac.exe" + gap + "-classpath " + gap + classpath + gap + Options + gap + g);

	      inp = new InputStreamReader(ps.getErrorStream());
				bufred = new BufferedReader(inp);

				while((line=bufred.readLine())!=null)
				{
					jtacomp.append(line + "\n");
					javacerror = true;
					win.stopRun(javacerror);
				}

				inp.close();
				bufred.close();
			}
			catch (Exception err)
			{
	    	System.out.println("error compiling " + g + " " + err.getMessage());
	    	Utils.userMessage("Error", "An error has occured, please see error log.", 1);
	    	Utils.writeErrorLog("error compiling " + g + " " + err.getMessage());
	    	win.setConsole("error compiling " + g + " " + err.getMessage());
	    	killThread();
	    	return;

	    }
	    finally
	    {
	      ps = null;
	      inp = null;
		    bufred = null;
	    }

	    win.clearConsole();

	    String outputString = jdk + fileSep + "javac.exe" + gap + "-classpath " + gap + classpath + gap + Options + gap + new File(g).getName().toString();

			if(javacerror)
			{
				win.setConsole(outputString + "\n" + jtacomp.getText());
				javacerror = false;
			}
			else
			{
			  win.setConsole(outputString + "\n" + "Compile Successful");
			}

		}
		else
	  {
	  	win.clearConsole();
			win.setConsole("Invalid SDK path and/or java options specified");
	  }

    killThread();
 }


}




